@@ -70,6 +70,8 @@ class SensorPushBluetoothDeviceData(BluetoothData):
     def _start_update(self, service_info: BluetoothServiceInfo) -> None:
         """Update from BLE advertisement data."""
         manufacturer_data = service_info.manufacturer_data
+        if not manufacturer_data:
+            return
         local_name = service_info.name
         result = {}
         device_type = None
@@ -87,6 +89,7 @@ class SensorPushBluetoothDeviceData(BluetoothData):
             result.update(decode_values(data, device_type_id))
 
         if device_type:
+            self.set_device_manufacturer("SensorPush")
             self.set_device_type(device_type)
             if service_info.name.startswith("SensorPush "):
                 self.set_device_name(service_info.name[11:])
